%bcond_with bootstrap

%global upstream_version %(echo %{version} | tr '~' '-')

Name:           hamcrest
Version:        2.2
Release:        %mkrel 3
Group:          Development/Java
Summary:        Library of matchers for building test expressions
License:        BSD
URL:            https://github.com/hamcrest/JavaHamcrest
BuildArch:      noarch

Source0:        https://github.com/hamcrest/JavaHamcrest/archive/v%{upstream_version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/hamcrest/hamcrest/%{upstream_version}/hamcrest-%{upstream_version}.pom

Patch0:         0001-Fix-build-with-OpenJDK-11.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  maven-surefire-provider-junit
%endif

Provides:       hamcrest-core = %{version}-%{release}
Obsoletes:      hamcrest-core < 1.3-32
Obsoletes:      hamcrest-demo < 1.3-32

%description
Provides a library of matcher objects (also known as constraints or predicates)
allowing 'match' rules to be defined declaratively, to be used in other
frameworks. Typical scenarios include testing frameworks, mocking libraries and
UI validation rules.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n JavaHamcrest-%{upstream_version}
%patch0 -p1

rm -rf docs
rm -rf *gradle*
rm -rf */*.gradle

mv hamcrest/src .
rm -rf hamcrest
rm -rf hamcrest-core
rm -rf hamcrest-integration
rm -rf hamcrest-library

cp -p %{SOURCE1} pom.xml
%pom_add_dep junit:junit::test
%pom_xpath_inject pom:project '
<build>
	<plugins>
		<plugin>
		<groupId>org.apache.maven.plugins</groupId>
		<artifactId>maven-compiler-plugin</artifactId>
		<version>3.8.1</version>
		<configuration>
			<source>1.8</source>
			<target>1.8</target>
		</configuration>
		</plugin>
	</plugins>
</build>'

%mvn_alias org.hamcrest:hamcrest org.hamcrest:hamcrest-all
%mvn_alias org.hamcrest:hamcrest org.hamcrest:hamcrest-core
%mvn_alias org.hamcrest:hamcrest org.hamcrest:hamcrest-library

sed -i 's/\r//' LICENSE.txt

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc README.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt



%changelog
* Mon Jul 25 2022 neoclust <neoclust> 2.2-3.mga9
+ Revision: 1871166
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 2.2-2.mga9
+ Revision: 1870264
- Fix BR for bootstrap

* Wed Jun 08 2022 neoclust <neoclust> 2.2-1.mga9
+ Revision: 1863537
- New version 2.2
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Sep 05 2020 daviddavid <daviddavid> 0:1.3-25.mga8
+ Revision: 1622302
- Use source/target 1.6 to build against Java 11
- Disable checking of remote javadoc links
- Rebuilt for JDK-11

* Wed Feb 12 2020 umeabot <umeabot> 0:1.3-24.mga8
+ Revision: 1501545
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0:1.3-23.mga7
+ Revision: 1278650
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 daviddavid <daviddavid> 0:1.3-22.mga7
+ Revision: 1168349
- Elimitate race condition when injecting JAR manifest (sync with fc27)
- Resolves: rhbz#1495234
- Remove bogus hamcrest-text JAR
- Fix mistake in mvn_artifact invocation
- Install with XMvn
- Update upstream URL
- Build from github source
- Specfile cleanup

* Wed Mar 02 2016 neoclust <neoclust> 0:1.3-15.mga6
+ Revision: 982614
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 0:1.3-14.mga6
+ Revision: 977190
- First rebuild of the java stack
- sync package hamcrest with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Oct 31 2015 daviddavid <daviddavid> 0:1.3-7.mga6
+ Revision: 896847
- sync with fc24:
  * Disable javadoc doclint
  * Add obsoletes in core to the main package to ease updates
  * Split hamcrest-core subpackage to allow other frameworks to reduce deps

* Tue Jan 13 2015 pterjan <pterjan> 0:1.3-6.mga5
+ Revision: 810468
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.3-5.mga5
+ Revision: 746551
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.3-4.mga5
+ Revision: 680071
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0:1.3-3.mga4
+ Revision: 537730
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 0:1.3-2.mga4
+ Revision: 487547
- Update osgi manifests.
  Build against easymock3

* Fri Jul 12 2013 dmorgan <dmorgan> 0:1.3-1.mga4
+ Revision: 453416
- New version

* Sat Jan 12 2013 umeabot <umeabot> 0:1.1-14.mga4
+ Revision: 353073
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:1.1-13.mga3
+ Revision: 325623
- Remove attributes in Export-Package header of hamcrest-core

* Wed Sep 12 2012 dmorgan <dmorgan> 0:1.1-12.mga3
+ Revision: 293019
- Clean specfile

* Fri Jun 29 2012 dmorgan <dmorgan> 0:1.1-11.mga3
+ Revision: 265198
- Rebuild against new java

* Sat Dec 10 2011 dmorgan <dmorgan> 0:1.1-3.mga2
+ Revision: 179953
- Do not BR/R openjdk6 but java >= 0:1.6.0
- Adapt to current guidelines.

* Tue Jan 18 2011 dmorgan <dmorgan> 0:1.1-2.0.4.mga1
+ Revision: 21785
- Fix release
- Sync with fedora
- imported package hamcrest


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1-2.0.4mdv2011.0
+ Revision: 605850
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.1-2.0.3mdv2010.1
+ Revision: 522835
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.1-2.0.2mdv2010.0
+ Revision: 425139
- rebuild

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0:1.1-2.0.1mdv2009.0
+ Revision: 264653
- rebuild early 2009.0 package (before pixel changes)

* Wed Apr 16 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.1-1.0.1mdv2009.0
+ Revision: 194992
- BR java-rpmbuild
- add ant.jar to classpath also
- try again to fix ant-launcher
- really add ant-launcher
- add ant-launcher to the classpath
- import hamcrest


